-- Options Panel Functions

function MinimalArchaeology:OptionsLoad()
	MinimalArchaeologyOptionPanel.AddonName:SetText("Minimal Archaeology");
	MinimalArchaeologyOptionPanel.AddonVersion:SetText(GetAddOnMetadata("MinimalArchaeology", "Version"));
	MinimalArchaeologyOptionPanel.name = "Minimal Archaeology";
	
	MinimalArchaeologyOptionPanel.hideArtifact.title:SetText("Hide Artifact Bar");
	MinimalArchaeologyOptionPanel.useKeystones.title:SetText("Always Use Keystones");
	MinimalArchaeologyOptionPanel.miscOptions.title:SetText("Miscellaneous Options");
	
	MinimalArchaeologyOptionPanelFrameScale.title:SetText("Scale");
	MinimalArchaeologyOptionPanelFrameScaleSliderLow:SetText("30");
	MinimalArchaeologyOptionPanelFrameScaleSliderHigh:SetText("100");
	MinimalArchaeologyOptionPanel.frameScale.slider:SetMinMaxValues(30, 100);
	MinimalArchaeologyOptionPanel.frameScale.slider:SetValueStep(5);
	
	MinimalArchaeologyOptionPanel.okay = MinimalArchaeologyOptionPanel:Hide();
	MinimalArchaeologyOptionPanel.cancel = MinimalArchaeologyOptionPanel:Hide();
		
	InterfaceOptions_AddCategory(MinimalArchaeologyOptionPanel);
end

function MinimalArchaeology:HideOptionToolTip(HideID)
	if (MinimalArchaeologyIsReady == true) then
		GameTooltip:SetOwner(MinimalArchaeologyOptionPanel.hideArtifact, "ANCHOR_TOPLEFT");
		GameTooltip:AddLine("Hide the "..MinimalArchaeology['artifacts'][HideID]['race'].." artifact bar even if it has been discovered.", 1.0, 1.0, 1.0, 1);
		GameTooltip:Show();
	end
end

function MinimalArchaeology:UseKeystoneOptionToolTip(UseKeystoneID)
	if (MinimalArchaeologyIsReady == true) then
		local RuneName, _, _, _, _, _, _, _, _, _ = GetItemInfo(MinimalArchaeology['artifacts'][UseKeystoneID]['raceitemid']);
		local RaceName = MinimalArchaeology['artifacts'][UseKeystoneID]['race'];
		
		if (RuneName ~= nil and RaceName ~= nil) then
			GameTooltip:SetOwner(MinimalArchaeologyOptionPanel.useKeystones, "ANCHOR_TOPLEFT");
			GameTooltip:AddLine("Always use all available "..RuneName.."s to solve "..RaceName.." artifacts.", 1.0, 1.0, 1.0, 1);
			GameTooltip:Show();
		end
	end
end

function MinimalArchaeology:MiscOptionToolTip(MiscID)
	GameTooltip:SetOwner(MinimalArchaeologyOptionPanel.miscOptions, "ANCHOR_TOPLEFT");
	
	if (MiscID == 1) then
		GameTooltip:AddLine("Hide the Minimap button.", 1.0, 1.0, 1.0, 1);
	elseif (MiscID == 2) then
		GameTooltip:AddLine("Disable the sound that is played when an artifact can be solved.", 1.0, 1.0, 1.0, 1);
	elseif (MiscID == 3) then
		GameTooltip:AddLine("Always start Minimal Archaeology hidden.", 1.0, 1.0, 1.0, 1);
	elseif (MiscID == 4) then
		GameTooltip:AddLine("Hide Minimal Archaeology after completing a digsite.", 1.0, 1.0, 1.0, 1);
	elseif (MiscID == 5) then
		GameTooltip:AddLine("Wait until all artifacts are solved before auto-hiding.", 1.0, 1.0, 1.0, 1);
	end
	
	GameTooltip:Show();
end

function MinimalArchaeology:HideOptionToggle()
	if (MinimalArchaeologyIsReady == true) then
		for i=1, 10 do
			if (MinimalArchaeologyOptionPanel.hideArtifact["hide"..i]:GetChecked() == 1) then
				MinimalArchaeologyHideOptions[i]['Hide'] = true;
			else
				MinimalArchaeologyHideOptions[i]['Hide'] = false;
			end
		end
	end
	MinimalArchaeology:UpdateMinArch();
end

function MinimalArchaeology:UseKeystoneOptionToggle()
	if (MinimalArchaeologyIsReady == true) then
		for i=1, 10 do
			if (i ~= 3 and i ~= 10) then
				if (MinimalArchaeologyOptionPanel.useKeystones["usekeystone"..i]:GetChecked() == 1) then
					MinimalArchaeologyArtifactOptions[i]['AlwaysUseKeystone'] = true;
				else
					MinimalArchaeologyArtifactOptions[i]['AlwaysUseKeystone'] = false;
				end
			end
		end
	end
	MinimalArchaeology:UpdateMinArch();
end

function MinimalArchaeology:MiscOptionsToggle()
	if (MinimalArchaeologyIsReady == true) then
		-- Hide Minimap button
		if (MinimalArchaeologyOptionPanel.miscOptions.hideMinimap:GetChecked() == 1) then
			MinimalArchaeologyOptions['HideMinimap'] = true;
			MinimalArchaeologyMinimapButton:Hide();
		else
			MinimalArchaeologyOptions['HideMinimap'] = false;
			MinimalArchaeologyMinimapButton:Show();
		end
		
		-- Disable Sound
		if (MinimalArchaeologyOptionPanel.miscOptions.disableSound:GetChecked() == 1) then
			MinimalArchaeologyOptions['DisableSound'] = true;
		else
			MinimalArchaeologyOptions['DisableSound'] = false;
		end
		
		-- Start hidden
		if (MinimalArchaeologyOptionPanel.miscOptions.startHidden:GetChecked() == 1) then
			MinimalArchaeologyOptions['StartHidden'] = true;
		else
			MinimalArchaeologyOptions['StartHidden'] = false;
		end
		
		-- Hide after completing a digsite
		if (MinimalArchaeologyOptionPanel.miscOptions.hideAfter:GetChecked() == 1) then
			MinimalArchaeologyOptions['HideAfterDigsite'] = true;
			MinimalArchaeologyOptionPanel.miscOptions.waitSolve:Enable();
			MinimalArchaeologyOptionPanel.miscOptions.waitSolve.text:SetAlpha(1.0);
		else
			MinimalArchaeologyOptions['HideAfterDigsite'] = false;
			MinimalArchaeologyOptionPanel.miscOptions.waitSolve:Disable();
			MinimalArchaeologyOptionPanel.miscOptions.waitSolve.text:SetAlpha(0.5);
		end
		
		-- Wait to solve artifacts
		if (MinimalArchaeologyOptionPanel.miscOptions.waitSolve:GetChecked() == 1) then
			MinimalArchaeologyOptions['WaitForSolve'] = true;
		else
			MinimalArchaeologyOptions['WaitForSolve'] = false;
		end
	end
end

function MinimalArchaeology:ScaleOptionsAdjust()
	if (MinimalArchaeologyIsReady == true) then
		MinimalArchaeologyOptions['FrameScale'] = MinimalArchaeologyOptionPanel.frameScale.slider:GetValue();
		MinimalArchaeologyOptionPanelFrameScaleSliderText:SetText(tostring(MinimalArchaeologyOptions['FrameScale']));
		MinimalArchaeologyFrame:SetScale(tonumber(MinimalArchaeologyOptions['FrameScale'])/100);
	end
end

function MinimalArchaeology:OpenOptions()
	if (MinimalArchaeologyIsReady == true) then
		MinimalArchaeology:UpdateMinArch();
		for i=1, 10 do
			MinimalArchaeologyOptionPanel.hideArtifact["hide"..i].text:SetText(MinimalArchaeology['artifacts'][i]['race']);
			MinimalArchaeologyOptionPanel.hideArtifact["hide"..i]:SetChecked(MinimalArchaeologyHideOptions[i]['Hide']);
			if (i ~= 3 and i ~= 10) then
				MinimalArchaeologyOptionPanel.useKeystones["usekeystone"..i].text:SetText(MinimalArchaeology['artifacts'][i]['race']);
				MinimalArchaeologyOptionPanel.useKeystones["usekeystone"..i]:SetChecked(MinimalArchaeologyArtifactOptions[i]['AlwaysUseKeystone']);
			end
		end
		
		-- Misc Options
		MinimalArchaeologyOptionPanel.miscOptions.hideMinimap.text:SetText("Hide the Minimap Button");
		MinimalArchaeologyOptionPanel.miscOptions.hideMinimap:SetChecked(MinimalArchaeologyOptions['HideMinimap']);
		
		MinimalArchaeologyOptionPanel.miscOptions.disableSound.text:SetText("Disable Sound");
		MinimalArchaeologyOptionPanel.miscOptions.disableSound:SetChecked(MinimalArchaeologyOptions['DisableSound']);

		MinimalArchaeologyOptionPanel.miscOptions.startHidden.text:SetText("Always Start Hidden");
		MinimalArchaeologyOptionPanel.miscOptions.startHidden:SetChecked(MinimalArchaeologyOptions['StartHidden']);

		MinimalArchaeologyOptionPanel.miscOptions.hideAfter.text:SetText("Auto-Hide After Digsites");
		MinimalArchaeologyOptionPanel.miscOptions.hideAfter:SetChecked(MinimalArchaeologyOptions['HideAfterDigsite']);
	
		MinimalArchaeologyOptionPanel.miscOptions.waitSolve.text:SetText("Wait to Solve Artifacts");
		if (MinimalArchaeologyOptions['HideAfterDigsite'] == false) then
			MinimalArchaeologyOptionPanel.miscOptions.waitSolve:Disable();			
			MinimalArchaeologyOptionPanel.miscOptions.waitSolve.text:SetAlpha(0.5);
		end
		MinimalArchaeologyOptionPanel.miscOptions.waitSolve:SetChecked(MinimalArchaeologyOptions['WaitForSolve']);
		
		-- Scale
		MinimalArchaeologyOptionPanelFrameScaleSliderText:SetText(tostring(MinimalArchaeologyOptions['FrameScale']));
		MinimalArchaeologyOptionPanel.frameScale.slider:SetValue(MinimalArchaeologyOptions['FrameScale']);
	end
end